@@ -60,9 +60,9 @@ class Espeak(AbstractSpeaker):
     def _process_config(**config):
         options = []
         if "volume" in config:
-            options += ['-a', str(config['volume'])]
-        if 'rate' in config:
-            options += ['-s', str(config['rate'])]
-        if 'voice' in config:
-            options += ['-v', str(config['voice'])]
+            options += ["-a", str(config["volume"])]
+        if "rate" in config:
+            options += ["-s", str(config["rate"])]
+        if "voice" in config:
+            options += ["-v", str(config["voice"])]
         return options
